@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2014 by the Quassel Project                        *
+ *   Copyright (C) 2005-2015 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,14 +53,7 @@ QSqlDatabase AbstractSqlStorage::logDb()
     if (!_connectionPool.contains(QThread::currentThread()))
         addConnectionToPool();
 
-    QSqlDatabase db = QSqlDatabase::database(_connectionPool[QThread::currentThread()]->name(),false);
-
-    if (!db.isOpen()) {
-        qWarning() << "Database connection" << displayName() << "for thread" << QThread::currentThread() << "was lost, attempting to reconnect...";
-        dbConnect(db);
-    }
-
-    return db;
+    return QSqlDatabase::database(_connectionPool[QThread::currentThread()]->name());
 }
 
 
@@ -97,12 +90,6 @@ void AbstractSqlStorage::addConnectionToPool()
         db.setPassword(password());
     }
 
-    dbConnect(db);
-}
-
-
-void AbstractSqlStorage::dbConnect(QSqlDatabase &db)
-{
     if (!db.open()) {
         quWarning() << "Unable to open database" << displayName() << "for thread" << QThread::currentThread();
         quWarning() << "-" << db.lastError().text();
